import type { APIRoute } from 'astro';

export const GET: APIRoute = async () => {
  try {
    // Only check environment variables at runtime, not build time
    const clientId = process.env.SPOTIFY_CLIENT_ID;
    const clientSecret = process.env.SPOTIFY_CLIENT_SECRET;
    const refreshToken = process.env.SPOTIFY_REFRESH_TOKEN;

    const isConfigured = !!(clientId && clientSecret && refreshToken);
    
    if (!isConfigured) {
      console.log('Spotify integration disabled - missing environment variables:', {
        hasClientId: !!clientId,
        hasClientSecret: !!clientSecret,
        hasRefreshToken: !!refreshToken
      });
    }

    return new Response(JSON.stringify({
      configured: isConfigured
    }), {
      status: 200,
      headers: {
        'Content-Type': 'application/json',
      },
    });

  } catch (error) {
    console.error('Error checking Spotify configuration:', error);
    return new Response(JSON.stringify({
      configured: false
    }), {
      status: 200,
      headers: {
        'Content-Type': 'application/json',
      },
    });
  }
}; 